@@ -2021,29 +2021,31 @@ Transform RegistrationVis::computeTransformationImpl(
 			}
 			for(unsigned int i=0; i<allInliers.size(); ++i)
 			{
-				if(_maxInliersMeanDistance>0.0f)
+				std::multimap<int, int>::const_iterator wordsIter = toSignature.getWords().find(allInliers[i]);
+				if(wordsIter != toSignature.getWords().end() && !toSignature.getWordsKpts().empty())
 				{
-					std::multimap<int, int>::const_iterator wordsIter = fromSignature.getWords().find(allInliers[i]);
-					if(wordsIter != fromSignature.getWords().end() && !fromSignature.getWords3().empty())
-					{
-						const cv::Point3f & pt = fromSignature.getWords3()[wordsIter->second];
-						if(uIsFinite(pt.x))
-						{
-							distances.push_back(util3d::transformPoint(pt, transformInv).x);
-						}
-					}
-				}
-
-				if(!pcaData.empty())
-				{
-					std::multimap<int, int>::const_iterator wordsIter = toSignature.getWords().find(allInliers[i]);
-					UASSERT(wordsIter != fromSignature.getWords().end() && !toSignature.getWordsKpts().empty());
-					float * ptr = pcaData.ptr<float>(i, 0);
 					const cv::KeyPoint & kpt = toSignature.getWordsKpts()[wordsIter->second];
 					int cameraIndex = (int)(kpt.pt.x / cameraModelsTo[0].imageWidth());
 					UASSERT_MSG(cameraIndex < (int)cameraModelsTo.size(), uFormat("cameraIndex=%d (x=%f models=%d camera width = %d)", cameraIndex, kpt.pt.x, (int)cameraModelsTo.size(), cameraModelsTo[0].imageWidth()).c_str());
-					ptr[0] = (kpt.pt.x-cameraIndex*cameraModelsTo[cameraIndex].imageWidth()-cameraModelsTo[cameraIndex].cx()) / cameraModelsTo[cameraIndex].imageWidth();
-					ptr[1] = (kpt.pt.y-cameraModelsTo[cameraIndex].cy()) / cameraModelsTo[cameraIndex].imageHeight();
+
+					if(_maxInliersMeanDistance>0.0f && !toSignature.getWords3().empty())
+					{
+						const cv::Point3f & pt = toSignature.getWords3()[wordsIter->second];
+						if(util3d::isFinite(pt))
+						{
+							UASSERT(cameraModelsTo[cameraIndex].isValidForProjection());
+
+							float depth = util3d::transformPoint(pt, cameraModelsTo[cameraIndex].localTransform().inverse()).z;
+							distances.push_back(depth);
+						}
+					}
+
+					if(!pcaData.empty())
+					{
+						float * ptr = pcaData.ptr<float>(i, 0);
+						ptr[0] = (kpt.pt.x-cameraIndex*cameraModelsTo[cameraIndex].imageWidth()-cameraModelsTo[cameraIndex].cx()) / cameraModelsTo[cameraIndex].imageWidth();
+						ptr[1] = (kpt.pt.y-cameraModelsTo[cameraIndex].cy()) / cameraModelsTo[cameraIndex].imageHeight();
+					}
 				}
 			}
 
