@@ -129,6 +129,13 @@ public:
 			break;
 		}
 		_pose=pose;
+		float r,p,yaw;
+		_pose.getEulerAngles(r, p, yaw);
+		if(_line)
+		{
+			float radius = this->rect().width()/2.0f;
+			_line->setLine(0,0,-radius*sin(yaw),-radius*cos(yaw));
+		}
 	}
 
 protected:
@@ -1704,16 +1711,9 @@ void GraphViewer::setOrientationENU(bool enabled)
 		_orientationENU = enabled;
 		this->rotate(_orientationENU?90:270);
 	}
-	if(_orientationENU)
-	{
-		QTransform t;
-		t.rotateRadians(_worldMapRotation);
-		_root->setTransform(t);
-	}
-	else
-	{
-		_root->resetTransform();
-	}
+	QTransform t;
+	t.rotateRadians(_worldMapRotation);
+	_root->setTransform(t);
 	if(_nodeItems.size() || _linkItems.size())
 	{
 		this->scene()->setSceneRect(this->scene()->itemsBoundingRect());  // Re-shrink the scene to it's bounding contents
@@ -1777,7 +1777,7 @@ void GraphViewer::restoreDefaults()
 
 void GraphViewer::wheelEvent ( QWheelEvent * event )
 {
-	if(event->delta() < 0)
+	if(event->angleDelta().y() < 0)
 	{
 		this->scale(0.95, 0.95);
 	}
@@ -2039,7 +2039,7 @@ void GraphViewer::contextMenuEvent(QContextMenuEvent * event)
 				if(QFileInfo(filePath).suffix().compare("pdf") == 0)
 				{
 					QPrinter printer(QPrinter::HighResolution);
-					printer.setOrientation(QPrinter::Portrait);
+					printer.setPageOrientation(QPageLayout::Portrait);
 					printer.setOutputFileName( filePath );
 					QPainter p(&printer);
 					scene()->render(&p);
